package com.sun.jmx.snmp;

import java.util.NoSuchElementException;
import java.util.StringTokenizer;

public class SnmpOid extends SnmpValue
{
    protected long[] components;
    protected int componentCount;
    static final String name = "Object Identifier";
    private static SnmpOidTable meta;
    static final long serialVersionUID = 8956237235607885096L;
    
    public SnmpOid() {
        this.components = null;
        this.componentCount = 0;
        this.components = new long[15];
        this.componentCount = 0;
    }
    
    public SnmpOid(long[] array) {
        this.components = null;
        this.componentCount = 0;
        this.components = (long[])array.clone();
        this.componentCount = this.components.length;
    }
    
    public SnmpOid(long n) {
        this.components = null;
        this.componentCount = 0;
        (this.components = new long[1])[0] = n;
        this.componentCount = this.components.length;
    }
    
    public SnmpOid(long n, long n2, long n3, long n4) {
        this.components = null;
        this.componentCount = 0;
        (this.components = new long[4])[0] = n;
        this.components[1] = n2;
        this.components[2] = n3;
        this.components[3] = n4;
        this.componentCount = this.components.length;
    }
    
    public SnmpOid(String resolveVarName) throws IllegalArgumentException {
        this.components = null;
        this.componentCount = 0;
        if (!resolveVarName.startsWith(".")) {
            try {
                resolveVarName = this.resolveVarName(resolveVarName);
            }
            catch (SnmpStatusException ex) {
                throw new IllegalArgumentException(ex.getMessage());
            }
        }
        StringTokenizer o = new StringTokenizer(resolveVarName, ".", false);
        this.componentCount = o.countTokens();
        if (this.componentCount == 0) {
            this.components = new long[15];
        }
        else {
            this.components = new long[this.componentCount];
            try {
                for (int i = 0; i < this.componentCount; ++i) {
                    try {
                        this.components[i] = Long.parseLong(o.nextToken());
                    }
                    catch (NoSuchElementException ex2) {}
                }
            }
            catch (NumberFormatException ex3) {
                throw new IllegalArgumentException(resolveVarName);
            }
        }
    }
    
    public int getLength() {
        return this.componentCount;
    }
    
    public long[] longValue() {
        long[] array = new long[this.componentCount];
        System.arraycopy(this.components, 0, array, 0, this.componentCount);
        return array;
    }
    
    public final long[] longValue(boolean b) {
        return this.longValue();
    }
    
    public final long getOidArc(int n) throws SnmpStatusException {
        try {
            return this.components[n];
        }
        catch (Exception ex) {
            throw new SnmpStatusException(6);
        }
    }
    
    public Long toLong() {
        if (this.componentCount != 1) {
            throw new IllegalArgumentException();
        }
        return new Long(this.components[0]);
    }
    
    public Integer toInteger() {
        if (this.componentCount != 1 || this.components[0] > 2147483647L) {
            throw new IllegalArgumentException();
        }
        return new Integer((int)this.components[0]);
    }
    
    @Override
    public String toString() {
        String s = "";
        if (this.componentCount >= 1) {
            for (int i = 0; i < this.componentCount - 1; ++i) {
                s = s + this.components[i] + ".";
            }
            s += this.components[this.componentCount - 1];
            return s;
        }
        return s;
    }
    
    public Boolean toBoolean() {
        if (this.componentCount != 1 && this.components[0] != 1L && this.components[0] != 2L) {
            throw new IllegalArgumentException();
        }
        return Boolean.valueOf(this.components[0] == 1L);
    }
    
    public Byte[] toByte() {
        Byte[] array = new Byte[this.componentCount];
        int i = 0;
        while (i < this.componentCount) {
            if (this.components[0] > 255L) {
                throw new IllegalArgumentException();
            }
            array[i] = new Byte((byte)(int)this.components[i]);
            ++i;
        }
        return array;
    }
    
    @Override
    public SnmpOid toOid() {
        long[] array = new long[this.componentCount];
        for (int i = 0; i < this.componentCount; ++i) {
            array[i] = this.components[i];
        }
        return new SnmpOid(array);
    }
    
    public static SnmpOid toOid(long[] array, int n) throws SnmpStatusException {
        try {
            if (array[n] > 2147483647L) {
                throw new SnmpStatusException(2);
            }
            int n2 = (int)array[n++];
            long[] array2 = new long[n2];
            for (int i = 0; i < n2; ++i) {
                array2[i] = array[n + i];
            }
            return new SnmpOid(array2);
        }
        catch (IndexOutOfBoundsException ex) {
            throw new SnmpStatusException(2);
        }
    }
    
    public static int nextOid(long[] array, int n) throws SnmpStatusException {
        try {
            if (array[n] > 2147483647L) {
                throw new SnmpStatusException(2);
            }
            n += (int)array[n++];
            if (n <= array.length) {
                return n;
            }
            throw new SnmpStatusException(2);
        }
        catch (IndexOutOfBoundsException ex) {
            throw new SnmpStatusException(2);
        }
    }
    
    public static void appendToOid(SnmpOid snmpOid, SnmpOid snmpOid2) {
        snmpOid2.append((long)snmpOid.getLength());
        snmpOid2.append(snmpOid);
    }
    
    @Override
    public final synchronized SnmpValue duplicate() {
        return (SnmpValue)this.clone();
    }
    
    public Object clone() {
        try {
            SnmpOid snmpOid = (SnmpOid)super.clone();
            snmpOid.components = new long[this.componentCount];
            System.arraycopy(this.components, 0, snmpOid.components, 0, this.componentCount);
            return snmpOid;
        }
        catch (CloneNotSupportedException ex) {
            throw new InternalError();
        }
    }
    
    public void insert(long n) {
        this.enlargeIfNeeded(1);
        for (int i = this.componentCount - 1; i >= 0; --i) {
            this.components[i + 1] = this.components[i];
        }
        this.components[0] = n;
        ++this.componentCount;
    }
    
    public void insert(int n) {
        this.insert((long)n);
    }
    
    public void append(SnmpOid snmpOid) {
        this.enlargeIfNeeded(snmpOid.componentCount);
        for (int i = 0; i < snmpOid.componentCount; ++i) {
            this.components[this.componentCount + i] = snmpOid.components[i];
        }
        this.componentCount += snmpOid.componentCount;
    }
    
    public void append(long n) {
        this.enlargeIfNeeded(1);
        this.components[this.componentCount] = n;
        ++this.componentCount;
    }
    
    public void addToOid(String s) throws SnmpStatusException {
        this.append(new SnmpOid(s));
    }
    
    public void addToOid(long[] array) throws SnmpStatusException {
        this.append(new SnmpOid(array));
    }
    
    public boolean isValid() {
        return this.componentCount >= 2 && 0L <= this.components[0] && this.components[0] < 3L && 0L <= this.components[1] && this.components[1] < 40L;
    }
    
    @Override
    public boolean equals(Object o) {
        boolean n = false;
        if ((o instanceof SnmpOid)) {
            SnmpOid snmpOid = (SnmpOid)o;
            if (snmpOid.componentCount == this.componentCount) {
                int n2 = 0;
                for (long[] components = snmpOid.components; n2 < this.componentCount && this.components[n2] == components[n2]; ++n2) {}
                n = (n2 == this.componentCount);
            }
        }
        return n;
    }
    
    @Override
    public int hashCode() {
        long n = 0L;
        for (int i = 0; i < this.componentCount; ++i) {
            n = n * 31L + this.components[i];
        }
        return (int)n;
    }
    
    public int compareTo(SnmpOid snmpOid) {
        int min;
        long[] components;
        int n;
        for (min = Math.min(this.componentCount, snmpOid.componentCount), components = snmpOid.components, n = 0; n < min && this.components[n] == components[n]; ++n) {}
        int n2;
        if (n == this.componentCount && n == snmpOid.componentCount) {
            n2 = 0;
        }
        else if (n == this.componentCount) {
            n2 = -1;
        }
        else if (n == snmpOid.componentCount) {
            n2 = 1;
        }
        else {
            n2 = ((this.components[n] < components[n]) ? -1 : 1);
        }
        return n2;
    }
    
    public String resolveVarName(String s) throws SnmpStatusException {
        int index = s.indexOf(46);
        try {
            return this.handleLong(s, index);
        }
        catch (NumberFormatException ex) {
            SnmpOidTable snmpOidTable = getSnmpOidTable();
            if (snmpOidTable == null) {
                throw new SnmpStatusException(2);
            }
            if (index <= 0) {
                return snmpOidTable.resolveVarName(s).getOid();
            }
            return snmpOidTable.resolveVarName(s.substring(0, index)).getOid() + s.substring(index);
        }
    }
    
    @Override
    public String getTypeName() {
        return "Object Identifier";
    }
    
    public static SnmpOidTable getSnmpOidTable() {
        return SnmpOid.meta;
    }
    
    public static void setSnmpOidTable(SnmpOidTable meta) {
        SecurityManager securityManager = System.getSecurityManager();
        if (securityManager != null) {
            securityManager.checkPermission(new SnmpPermission("setSnmpOidTable"));
        }
        SnmpOid.meta = meta;
    }
    
    public String toOctetString() {
        return new String(this.tobyte());
    }
    
    private byte[] tobyte() {
        byte[] array = new byte[this.componentCount];
        int i = 0;
        while (i < this.componentCount) {
            if (this.components[0] > 255L) {
                throw new IllegalArgumentException();
            }
            array[i] = (byte)(int)this.components[i];
            ++i;
        }
        return array;
    }
    
    private void enlargeIfNeeded(int n) {
        int length;
        for (length = this.components.length; this.componentCount + n > length; length *= 2) {}
        if (length > this.components.length) {
            long[] components = new long[length];
            for (int i = 0; i < this.components.length; ++i) {
                components[i] = this.components[i];
            }
            this.components = components;
        }
    }
    
    private String handleLong(String s, int endIndex) throws NumberFormatException, SnmpStatusException {
        String substring;
        if (endIndex > 0) {
            substring = s.substring(0, endIndex);
        }
        else {
            substring = s;
        }
        Long.parseLong(substring);
        return s;
    }
    
    static {
        SnmpOid.meta = null;
    }
}
